@@ -74,7 +74,7 @@ class Encryptor:
 
     def add_to_register(self, path: str, file_path: str, key=None):
         if path == "def":
-            if platform.system() == "windows":
+            if platform.system() == "Windows":
                 path = "".join([_ + "\\" for _ in __file__.split("\\")[:-1]]) + "data\\.register"
             else:
                 path = "".join([_ + "/" for _ in __file__.split("/")[:-1]]) + "data/.register"
@@ -165,7 +165,7 @@ class Decrypter:
 
     def decrypt_with_register(self, path: str):
         if path == "def":
-            if platform.system() == "windows":
+            if platform.system() == "Windows":
                 path = "".join([_ + "\\" for _ in __file__.split("\\")[:-1]]) + "data\\.register"
             else:
                 path = "".join([_ + "/" for _ in __file__.split("/")[:-1]]) + "data/.register"
